aboutsummaryrefslogtreecommitdiffstats
path: root/os/kernel/src/chmemcore.c
diff options
context:
space:
mode:
authorgdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2010-02-16 19:21:42 +0000
committergdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2010-02-16 19:21:42 +0000
commit0c85d7906646524a75121867ba02dd1bb809cd21 (patch)
treee47f6a218a4ebc0eef1fe9d60e7eadf4ef9ab6ff /os/kernel/src/chmemcore.c
parentb8e3f8794e1d3437ceb0b5a10226887b391e0c7b (diff)
downloadChibiOS-0c85d7906646524a75121867ba02dd1bb809cd21.tar.gz
ChibiOS-0c85d7906646524a75121867ba02dd1bb809cd21.tar.bz2
ChibiOS-0c85d7906646524a75121867ba02dd1bb809cd21.zip
Tentative fix for bug 2952961.
git-svn-id: svn://svn.code.sf.net/p/chibios/svn/trunk@1619 35acf78f-673a-0410-8e92-d51de3d6d3f4
Diffstat (limited to 'os/kernel/src/chmemcore.c')
-rw-r--r--os/kernel/src/chmemcore.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/os/kernel/src/chmemcore.c b/os/kernel/src/chmemcore.c
index 8269deb48..d5adbef48 100644
--- a/os/kernel/src/chmemcore.c
+++ b/os/kernel/src/chmemcore.c
@@ -43,17 +43,19 @@ void core_init(void) {
nextmem = &__heap_base__;
endmem = &__heap_end__;
#else
- static align_t buffer[MEM_ALIGN_SIZE(CH_MEMCORE_SIZE) / sizeof(align_t)];
+ static stkalign_t buffer[MEM_ALIGN_SIZE(CH_MEMCORE_SIZE) /
+ sizeof(stkalign_t)];
nextmem = (uint8_t *)&buffer[0];
- endmem = (uint8_t *)&buffer[MEM_ALIGN_SIZE(CH_MEMCORE_SIZE) / sizeof(align_t)];
+ endmem = (uint8_t *)&buffer[MEM_ALIGN_SIZE(CH_MEMCORE_SIZE) /
+ sizeof(stkalign_t)];
#endif
}
/**
* @brief Allocates a memory block.
* @details The size of the returned block is aligned to the alignment
* type @p align_t so it is not possible to allocate less than
* <code>sizeof(align_t)</code>.
*
*
* @param[in] size the size of the block to be allocated
@@ -43,17 +43,19 @@ void core_init(void) {
* @brief Allocates a memory block.
* @details The size of the returned block is aligned to the alignment
- * type @p align_t so it is not possible to allocate less than
- * <code>sizeof(align_t)</code>.
+ * type @p stkalign_t so it is not possible to allocate less
+ * than <code>sizeof(stkalign_t)</code>.
*
*